@@ -1,8 +1,9 @@
 # I basically took vars.pm, and turned it into vars/i.pm
 
 package Acme::CXW::vars::i;
+use 5.006;
 
-our $VERSION = '1.03'; # TRIAL
+our $VERSION = '1.04'; # TRIAL
 
 # yuck
 =for IT DOESN'T WORK nor is it important (try perl -Mstrict -Mwarnings=all -We"use vars q[$a];")
@@ -180,6 +181,11 @@ will die at compile time.
 
 See L<vars>, L<perldoc/"our">, L<perlmodlib/Pragmatic Modules>.
 
+=head1 MINIMUM PERL VERSION
+
+This version supports Perl 5.6+.  If you are running an earlier Perl,
+use version 1.01 of this module (PODMASTER/vars-i-1.01).
+
 =head1 AUTHORS
 
 D.H aka PodMaster, plus code from CXW.
